@@ -304,12 +304,13 @@ need to connect to the server first. try running "connect_to_socket"
         session: globals()
             your Python's session variables (i.e. "globals()")
         """
-        if _get_source(YhatModel.execute)==_get_source(model.execute):
-            msg = "'execute' method was not implemented. If you believe that you did"
+        if 1==2 and _get_source(YhatModel.execute)==_get_source(model.execute):
+            msg = "'execute' method was not implemented. If you believe that you did "
             msg += "implement the 'execute' method, check to make sure there isn't an "
             msg += "indentation error."
             raise Exception(msg)
 
+        
         bundle = save_function(model, session)
         bundle["largefile"] = True
         bundle["username"] = self.username
@@ -317,6 +318,10 @@ need to connect to the server first. try running "connect_to_socket"
         bundle["modelname"] = name
         bundle["className"] = model.__name__
         bundle["reqs"] = getattr(model, "REQUIREMENTS", "")
+        # make sure we freeze Yhat so we're sure we're using the right version
+        # this makes it a lot easier to upgrade the client
+        import yhat
+        bundle["reqs"] += '\n' + "yhat==" + yhat.__version__
         bundle["reqs"] = bundle["reqs"].strip()
         return bundle
     
